import spacy
from collections import Counter
import json
#need to install
#python -m spacy download en_core_web_sm


def read_json(filename):
    with open(filename, 'r',encoding='utf-8') as file:
        return json.load(file)

def word_frequency_dict(input_text):
    nlp = spacy.load("en_core_web_sm")
    doc = nlp(input_text)
    words = [token.text for token in doc if token.is_stop != True and token.is_punct != True]
    word_freq = Counter(words)
    c = dict(word_freq)
    return c

def count_keywords(source_dictionary, output_format='pydict'):
    output_dict = {'care':{'vice':{}, 'virtue':{}}, 'fairness':{'vice':{}, 'virtue':{}}, 'loyalty':{'vice':{}, 'virtue':{}}, 'authority':{'vice':{}, 'virtue':{}}, 'sanctity':{'vice':{}, 'virtue':{}}}
    lex = read_json('moral_foundations.json')
    for item in lex.keys():
        good = [(item, source_dictionary[item]) for item in lex[item]['virtue'] if item in source_dictionary]
        bad = [(item, source_dictionary[item]) for item in lex[item]['vice'] if item in source_dictionary] 
        good_changed = {k:v for (k,v) in good}
        bad_changed = {k:v for (k,v) in bad}
        output_dict[item]['virtue'] = good_changed
        output_dict[item]['vice'] = bad_changed
    if output_format == 'json':
        return json.dumps(output_dict)
    else:
        return output_dict


from auxilliary_functions import *


def read_file(filename):
    """
    Reads in a file as utf-8.
    :param filename: Filepath to the file to be read.
    """
    with open(filename, 'r',encoding='utf-8') as file:
        return file.read()

def moralize(input_text, output_format='pydict'):
    """
    Takes input text and returns format as either a Python dictionary or JSON object.
    :param input_text: Text you want to analyze.
    :param output_format: defaults to Python dictionary, enter '.json' for output in a JSON object.po
    """
    analyzed_text = word_frequency_dict(input_text)
    return count_keywords(analyzed_text, output_format)







# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['moralizer']

package_data = \
{'': ['*']}

install_requires = \
['spacy>=2.1,<3.0']

setup_kwargs = {
    'name': 'moralizer',
    'version': '0.1.1',
    'description': '> Simple tool to get the Moral Foundations counts of a given text.',
    'long_description': '# Moralizer\n> Simple tool to get the Moral Foundations counts of a given text. \n\n![MIT](https://img.shields.io/dub/l/vibe-d.svg?style=flat-square)\n![dependencies](https://img.shields.io/david/expressjs/express.svg?style=flat-square)\n![python](https://img.shields.io/badge/python-3.6%2C3.7-blue.svg?style=flat-square)\n\n## Installation\n```shell\npip install moralizer\n```\nSpaCy requires the following add-on.\n```shell\npython -m spacy download en_core_web_sm\n```\n## Description \nMoralizer returns word counts of a text based on the [Moral Foundations Vocabulary 2.0](https://osf.io/ezn37/) in a neat and organized JSON object or Python dictionary.\n\n## Use\nStructure\n- moralizer\n  - read_file(input_file)\n  - moralize(text, output_format=default is Python dictionary, add ".json" for output in JSON).\n\n\n## Dependencies\nMoralizer only uses one outside dependency, the delightfully opinionated [**spaCy**](https://spacy.io/).\n\n## Under Construction \n- Tests\n- Documentation',
    'author': 'npm',
    'author_email': None,
    'url': 'https://github.com/npmontgomery/moralizer',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
